﻿using System;
using Pdftools.Pdf;
using Pdftools.PdfSecure;

namespace dual
{
    class Program
    {
        static void Main(string[] args)
        {
            //インスタンス生成
            Secure doc = new Secure();
            doc.NoCache = true;

            //入力のPDFファイル
            if (!doc.Open("input.pdf", ""))
            {
                Console.WriteLine("入力ファイル\"input.pdf\"を開けません");
                Environment.Exit(1);
            }

            //署名
            PDFRect rect;

            Signature sig = new Signature();
            sig.Name = "Taro Yamada";
            sig.Issuer = "CA51-3";
            sig.SerialNumber = "10 a2";
            sig.Reason = "Received";
            sig.Location = "Tokyo";
            rect.lowerLeftX = 470; rect.lowerLeftY = 600;
            rect.upperRightX = 500; rect.upperRightY = 630;
            sig.Rect = rect;
            sig.StrokeColor = 10053120;
            sig.FillColor = 6724095;
            sig.Text1 = "\t0,0 ";
            sig.Text2 = "\t0,0 ";
            sig.ImageFileName = "hanko.png";
            sig.PageNo = -1;
            sig.TimeStampURL = "http://tsa.trustss.jp/";
            if (!doc.AddSignature(sig))
            {
                Console.WriteLine("電子署名できませんでした");
                Environment.Exit(2);
            }

            //PDFをメモリに出力
            if (!doc.SaveInMemory(null, null, (PDFPermission)(-1), 0, null, null))
            {
                Console.WriteLine("PDFをメモリに出力できませんでした");
                Environment.Exit(3);
            }
            doc.Close();

            //メモリ上のPDFを読み込む
            Secure doc2 = new Secure();
            doc2.NoCache = true;
            byte[] ps = doc.GetPdf();
            if (!doc2.OpenMem(ps, null))
            {
                Console.WriteLine("メモリからPDFを読み込めませんでした");
                Environment.Exit(4);
            }

            //次の電子署名
            PDFRect rect2;

            Signature sig2 = new Signature();
            sig2.Name = "Jiro Yamada";
            sig2.Issuer = "CA51-3";
            sig2.SerialNumber = "10 a3";
            sig2.Reason = "Received";
            sig2.Location = "Tokyo";
            rect2.lowerLeftX = 470; rect2.lowerLeftY = 565;
            rect2.upperRightX = 500; rect2.upperRightY = 595;
            sig2.Rect = rect2;
            sig2.StrokeColor = 10053120;
            sig2.FillColor = 6724095;
            sig2.Text1 = "\t0,0 ";
            sig2.Text2 = "\t0,0 ";
            sig2.ImageFileName = "hanko.png";
            sig2.PageNo = -1;
            sig2.TimeStampURL = "http://tsa.trustss.jp/";

            //次の電子署名を追加
            if (!doc2.AddSignature(sig2))
            {
                Console.WriteLine("電子署名できませんでした");
                Environment.Exit(5);
            }

            //結果をファイルに出力
            if (!doc2.SaveAs("output.pdf", null, null, (PDFPermission.ePermNoEncryption), 0, null, null))
            {
                Console.WriteLine("結果を出力できませんでした");
                Environment.Exit(6);
            }
            doc2.Close();
        }
    }
}
